@@ -44,7 +44,7 @@ def get_kpoints_path(structure, method='seekpath', **kwargs):
     :returns: dictionary as described above in the docstring
     """
     if method not in _GET_KPOINTS_PATH_METHODS.keys():
-        raise ValueError("the method '{}' is not implemented".format(method))
+        raise ValueError(f"the method '{method}' is not implemented")
 
     method = _GET_KPOINTS_PATH_METHODS[method]
 
@@ -80,7 +80,7 @@ def get_explicit_kpoints_path(structure, method='seekpath', **kwargs):
     :returns: dictionary as described above in the docstring
     """
     if method not in _GET_EXPLICIT_KPOINTS_PATH_METHODS.keys():
-        raise ValueError("the method '{}' is not implemented".format(method))
+        raise ValueError(f"the method '{method}' is not implemented")
 
     method = _GET_EXPLICIT_KPOINTS_PATH_METHODS[method]
 
@@ -118,7 +118,7 @@ def _seekpath_get_kpoints_path(structure, **kwargs):
     unknown_args = set(kwargs).difference(recognized_args)
 
     if unknown_args:
-        raise ValueError('unknown arguments {}'.format(unknown_args))
+        raise ValueError(f'unknown arguments {unknown_args}')
 
     return seekpath.get_kpoints_path(structure, kwargs)
 
@@ -158,7 +158,7 @@ def _seekpath_get_explicit_kpoints_path(structure, **kwargs):
     unknown_args = set(kwargs).difference(recognized_args)
 
     if unknown_args:
-        raise ValueError('unknown arguments {}'.format(unknown_args))
+        raise ValueError(f'unknown arguments {unknown_args}')
 
     return seekpath.get_explicit_kpoints_path(structure, kwargs)
 
@@ -178,7 +178,7 @@ def _legacy_get_kpoints_path(structure, **kwargs):
     args_unknown = set(kwargs).difference(args_recognized)
 
     if args_unknown:
-        raise ValueError('unknown arguments {}'.format(args_unknown))
+        raise ValueError(f'unknown arguments {args_unknown}')
 
     point_coords, path, bravais_info = legacy.get_kpoints_path(cell=structure.cell, pbc=structure.pbc, **kwargs)
 
@@ -210,7 +210,7 @@ def _legacy_get_explicit_kpoints_path(structure, **kwargs):
     args_unknown = set(kwargs).difference(args_recognized)
 
     if args_unknown:
-        raise ValueError('unknown arguments {}'.format(args_unknown))
+        raise ValueError(f'unknown arguments {args_unknown}')
 
     point_coords, path, bravais_info, explicit_kpoints, labels = legacy.get_explicit_kpoints_path(  # pylint: disable=unbalanced-tuple-unpacking
         cell=structure.cell, pbc=structure.pbc, **kwargs
